copyWith abstract method
Returns a shallow copy of this BulkQueryColumnDescription with some or all fields replaced by the given arguments.
Implementation
@_iss.useResult
BulkQueryColumnDescription copyWith({String? name});
Returns a shallow copy of this BulkQueryColumnDescription with some or all fields replaced by the given arguments.
@_iss.useResult
BulkQueryColumnDescription copyWith({String? name});