DatabaseMigrationVersion class abstract

Represents a version of a database migration with a table.

Inheritance

Constructors

DatabaseMigrationVersion({int? id, required String module, required String version, DateTime? timestamp})
factory
DatabaseMigrationVersion.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
The database id, set if the object has been inserted into the database or if it has been fetched from the database. Otherwise, the id will be null.
getter/setter pair
module String
The module the migration belongs to.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime?
The timestamp of the migration. Only set if the migration is applied.
getter/setter pairinherited
version String
The version of the migration.
getter/setter pairinherited

Methods

copyWith({int? id, String? module, String? version, Object? timestamp}) DatabaseMigrationVersion
Returns a shallow copy of this DatabaseMigrationVersion with some or all fields replaced by the given arguments.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited