CloudStorageDirectDownloadEntry class abstract
Grants temporary download access to a database-backed stored file.
Constructors
Properties
- authKey ↔ String
-
Opaque access key carried by the temporary URL.
getter/setter pair
- contentType ↔ String?
-
Optional response MIME type override.
getter/setter pair
- downloadFileName ↔ String?
-
Optional filename presented to the downloader.
getter/setter pair
- expiration ↔ DateTime
-
The expiration time of the temporary URL.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
- path ↔ String
-
The path of the file.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageId ↔ String
-
The storage containing the file.
getter/setter pair
Methods
-
copyWith(
{int? id, String? storageId, String? path, DateTime? expiration, String? authKey, String? downloadFileName, String? contentType}) → CloudStorageDirectDownloadEntry - Returns a shallow copy of this CloudStorageDirectDownloadEntry with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toJsonForProtocol(
) → Map< String, dynamic> - Returns a JSON structure of the model, optimized for Protocol communication.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited