IntervalFutureCallScheduling class abstract
- Inheritance
-
- Object
- FutureCallScheduling
- IntervalFutureCallScheduling
Constructors
- IntervalFutureCallScheduling({required Duration interval, DateTime? start})
-
factory
-
IntervalFutureCallScheduling.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval ↔ Duration
-
Interval for recurring calls
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start ↔ DateTime?
-
Optional start time for the first execution
getter/setter pair
Methods
-
copyWith(
{Duration? interval, DateTime? start}) → IntervalFutureCallScheduling -
Returns a shallow copy of this IntervalFutureCallScheduling
with some or all fields replaced by the given arguments.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited