ServiceAuthKeyProvider class
The key manager used for the service protocol.
Constructors
- ServiceAuthKeyProvider(String name, ServerpodConfig config)
- Creates a new ServiceAuthKeyProvider.
- ServiceAuthKeyProvider.withServiceSecret(String name, String? serviceSecret)
- Creates a new ServiceAuthKeyProvider with a service secret.
Properties
-
authHeaderValue
→ Future<
String?> -
A valid authentication header value. Should be used for all requests.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Name of the client
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceSecret → String?
-
Server configuration.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited